==> text2music-0.1.1.tar.gz: text2music-0.1.1/README.md <==
# Text-to-Music Generation
This is the Github Repository for the project "Text-to-Music Generation".

- To have some intuition about how this works, check this huggingface space: https://huggingface.co/spaces/Mubert/Text-to-Music
- Currently, we are in a stage where we should check related work and communicate ideas. Later, once we have some creative ideas, we can make plans and start implementation.
- This is an open-source project, so you're welcome to come up with ideas at any time or directly contribute to the GitHub repository.

You're welcome to join our [discord server](https://discord.gg/GbpJrQuNdg) to share your thoughts and report feedbacks!


## Roadmap
- [ ] check related work
- [ ] make a plan/timeline
- [ ] start implementation

## Quick Start
1. installation: 
      ```
      pip install text2music
      ```
2. experimental example:
      ```python
      import text2music as t2m
      t2m.experimental.mubert_generate('this is a prompt', 10, 'test.mp3')
      ```



## Contribution
If you have any ideas about text-to-music, feel free to discuss in the discord server!

Or, if you want to contribute the codes, simply open a pull request!

We appreciate your contribution!

## Active Line of Work
1. we are collecting real user prompts for later dataset building. If you would like to share your ideas, fill this [google form](https://forms.gle/Fmp8aSU3f6ThmeaT9) and submit. We really appreciate your help and will add you to the "wall of love" later:)
2. We are currently building our website: https://nlp-guild.github.io/text2music/. You're welcome to contribute 🙂

==> text2music-0.1.2.tar.gz: text2music-0.1.2/README.md <==
# Text-to-Music Generation
This is the Github Repository for the project "Text-to-Music Generation".

- To have some intuition about how this works, check this huggingface space: https://huggingface.co/spaces/Mubert/Text-to-Music
- Currently, we are in a stage where we should check related work and communicate ideas. Later, once we have some creative ideas, we can make plans and start implementation.
- This is an open-source project, so you're welcome to come up with ideas at any time or directly contribute to the GitHub repository.

You're welcome to join our [discord server](https://discord.gg/GbpJrQuNdg) to share your thoughts and report feedbacks!


## Roadmap
- [ ] check related work
- [ ] make a plan/timeline
- [ ] start implementation

## Quick Start
> **Recommended Python Version: 3.7**
1. installation: 
      ```
      pip install text2music
      ```
2. experimental example:
      ```python
      import text2music as t2m
      t2m.experimental.mubert_generate('I am quite happy today', 10, 'test.mp3')
      ```



## Contribution
If you have any ideas about text-to-music, feel free to discuss in the discord server!

Or, if you want to contribute the codes, simply open a pull request!

We appreciate your contribution!

## Active Line of Work
1. we are collecting real user prompts for later dataset building. If you would like to share your ideas, fill this [google form](https://forms.gle/Fmp8aSU3f6ThmeaT9) and submit. We really appreciate your help and will add you to the "wall of love" later:)
2. We are currently building our website: https://nlp-guild.github.io/text2music/. You're welcome to contribute 🙂
